Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Info ¶
type Info struct {
Available bool
GoVersion string
GoArch string
GoOs string
// CgoEnabled indicates whether cgo was enabled when this build was created.
CgoEnabled bool
// GitRevision is the git revision associated with this build.
GitRevision string
// GitTime is the git revision time.
GitTime time.Time
GitModified bool
}
var (
InfoData Info
)
Click to show internal directories.
Click to hide internal directories.